summaryrefslogtreecommitdiffstats
path: root/screenshot.h
diff options
context:
space:
mode:
Diffstat (limited to 'screenshot.h')
-rw-r--r--screenshot.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/screenshot.h b/screenshot.h
index 207d58e003..c57778c0b3 100644
--- a/screenshot.h
+++ b/screenshot.h
@@ -25,9 +25,11 @@ struct MPContext;
struct mp_image;
// Request a taking & saving a screenshot of the currently displayed frame.
-// If each_frame is set, this toggles per-frame screenshots, exactly like the
-// screenshot slave command (MP_CMD_SCREENSHOT).
-void screenshot_request(struct MPContext *mpctx, bool each_frame);
+// each_frame: If set, this toggles per-frame screenshots, exactly like the
+// screenshot slave command (MP_CMD_SCREENSHOT).
+// full_window: If set, save the actual output window contents.
+void screenshot_request(struct MPContext *mpctx, bool each_frame,
+ bool full_window);
// Save the screenshot contained in the image to disk.
// The image can be in any format supported by libswscale.